==> nextcloud-25.0.8.tgz: nextcloud/apps/user_status/l10n/eu.js <==
OC.L10N.register(
    "user_status",
    {
    "Recent statuses" : "Azken egoerak",
    "In a meeting" : "Bilera batean",
    "Commuting" : "Lanerako bidean",
    "Out sick" : "Gaixorik",
    "Vacationing" : "Oporretan",
    "Working remotely" : "Urrutitik lanean",
    "In a call" : "Dei batean",
    "User status" : "Erabiltzaile-egoera",
    "View profile" : "Ikusi profila",
    "Clear status after" : "Garbitu egoera honen ondoren",
    "What is your status?" : "Zein da zure egoera?",
    "Previously set" : "Lehendik ezarrita",
    "Reset status" : "Berrezarri egoera",
    "Set status" : "Ezarri egoera",
    "Online status" : "Lineako egoera",
    "Status message" : "Egoera-mezua",
    "Clear status message" : "Garbitu egoera-mezua",
    "Set status message" : "Ezarri egoera-mezua",
    "There was an error saving the status" : "Errore bat gertatu da egoera gordetzean",
    "There was an error clearing the status" : "Errore bat gertatu da egoera garbitzean",
    "No recent status changes" : "Azken egoera-aldaketarik ez",
    "Away" : "Kanpoan",
    "Do not disturb" : "Ez molestatu",
    "{status}, {timestamp}" : "{status}, {timestamp}",
    "Don't clear" : "Ez garbitu",
    "Today" : "Gaur",
    "This week" : "Aste honetan",
    "Online" : "Linean",
    "Invisible" : "Ikusezina",
    "Offline" : "Lineaz kanpo",
    "There was an error saving the new status" : "Errore bat gertatu da egoera berria gordetzean",
    "30 minutes" : "30 minutu",
    "1 hour" : "Ordu 1",
    "4 hours" : "4 ordu",
    "Mute all notifications" : "Mututu jakinarazpen guztiak",
    "Appear offline" : "Lineaz kanpo agertu"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-25.0.12p1.tgz: nextcloud/apps/user_status/l10n/eu.js <==
OC.L10N.register(
    "user_status",
    {
    "Recent statuses" : "Azken egoerak",
    "No recent status changes" : "Azken egoera-aldaketarik ez",
    "In a meeting" : "Bilera batean",
    "Commuting" : "Lanerako bidean",
    "Out sick" : "Gaixorik",
    "Vacationing" : "Oporretan",
    "Working remotely" : "Urrutitik lanean",
    "In a call" : "Dei batean",
    "User status" : "Erabiltzaile-egoera",
    "View profile" : "Ikusi profila",
    "Clear status after" : "Garbitu egoera honen ondoren",
    "Emoji for your status message" : "Zure egoera-mezurako emojia",
    "What is your status?" : "Zein da zure egoera?",
    "Predefined statuses" : "Aurrez definitutako egoerak",
    "Previously set" : "Lehendik ezarrita",
    "Reset status" : "Berrezarri egoera",
    "Set status" : "Ezarri egoera",
    "Online status" : "Lineako egoera",
    "Status message" : "Egoera-mezua",
    "Your status was set automatically" : "Zure egoera automatikoki ezarriko dira",
    "Clear status message" : "Garbitu egoera-mezua",
    "Set status message" : "Ezarri egoera-mezua",
    "Reset status to \"{icon} {message}\"" : "Berrezarri egoera \"{icon} {message}\"(e)ra",
    "Reset status to \"{message}\"" : "Berrezarri egoera \"{message}\"(e)ra",
    "Reset status to \"{icon}\"" : "Berrezarri egoera \"{icon}\"(e)ra",
    "There was an error saving the status" : "Errore bat gertatu da egoera gordetzean",
    "There was an error clearing the status" : "Errore bat gertatu da egoera garbitzean",
    "There was an error reverting the status" : "Errore bat gertatu da egoera berrezartzean",
    "Don't clear" : "Ez garbitu",
    "Today" : "Gaur",
    "This week" : "Aste honetan",
    "Online" : "Linean",
    "Away" : "Kanpoan",
    "Do not disturb" : "Ez molestatu",
    "Invisible" : "Ikusezina",
    "Offline" : "Lineaz kanpo",
    "There was an error saving the new status" : "Errore bat gertatu da egoera berria gordetzean",
    "30 minutes" : "30 minutu",
    "1 hour" : "Ordu 1",
    "4 hours" : "4 ordu",
    "Mute all notifications" : "Mututu jakinarazpen guztiak",
    "Appear offline" : "Lineaz kanpo agertu",
    "{status}, {timestamp}" : "{status}, {timestamp}"
},
"nplurals=2; plural=(n != 1);");
